/**
 * KinoTrend plugin for Movian Media Center
 *
 *  Copyright (C) 2019 Nemiroff
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

(function (plugin) {

	var logo = plugin.path + "logo.png";
	var pluginDescriptor = plugin.getDescriptor();
	var service = plugin.createService(pluginDescriptor.title, pluginDescriptor.id + ":start", "video", true, logo);
	var settings = plugin.createSettings(pluginDescriptor.title, logo, pluginDescriptor.synopsis);
	var magnetTrackers = null;

	settings.createString("trackers", "Additional tracker list to use", "https://raw.githubusercontent.com/ngosang/trackerslist/master/trackers_best_ip.txt", function (v) {
		try {
			magnetTrackers = '&tr=' + showtime.httpReq(v).toString().replace(/\n+/g, '&tr=');
		} catch (e) {

		}
	});
	var url = 'http://kinotrend.ml/movies.json'
	var blue = '6699CC',
		orange = 'FFA500',
		red = 'EE0000',
		green = '008B45';

	function colorStr(str, color) {
		return '<font color="' + color + '">' + str + '</font>';
	}

	function coloredStr(str, color) {
		return '<font color="' + color + '">' + str + '</font>';
	}

	function mapSearchResults(page, movies) {
		for (var i = 0; i < movies.length; i++) {
			var item = movies[i];
			page.appendItem(plugin.getDescriptor().id + ":movie:" + item.filmID.toString(), "video", {
				title: item.nameRU,
				year: parseInt(item.year, 10),
				genre: item.genre,
				rating: parseInt(item.rating, 10)* 10,
				tagline: item.slogan,
				icon: item.posterURL,
				backdrops: item.bigPosterURL,
				duration: item.filmLength+":00",
				description: item.description
			});
		}
	}

	function setPageHeader(page, title, icon) {
		page.type = "directory";
		page.contents = "items";
		page.metadata.logo = logo;
		page.metadata.icon = logo;
		page.metadata.title = new showtime.RichText(title);
	}

	plugin.addURI(plugin.getDescriptor().id + ":start", function (page) {
		setPageHeader(page, plugin.getDescriptor().title);
		page.loading = true;
		var doc = showtime.httpReq(url).toString();
		doc = showtime.JSONDecode(doc);
		if (doc) {
			mapSearchResults(page, doc.movies);
		}
		page.loading = false;
	});

	plugin.addURI(plugin.getDescriptor().id + ":movie:(.*)", function (page, id) {
		setPageHeader(page, plugin.getDescriptor().title);
		page.loading = true;
		var doc = showtime.httpReq(url).toString();
		doc = showtime.JSONDecode(doc);

		if (doc) {
			var docs = doc.movies
			for (var i = 0; i < docs.length; i++) {
				if (docs[i].filmID.toString() == id) {
					for (var y = 0; y < docs[i].torrents.length; y++) {
						var torrentInfo = docs[i].torrents[y]
						var magnetLink = torrentInfo.magnet;
						var torIcon = "rutor.png"
						if (magnetLink.indexOf("kinozal") !== -1) {
							torIcon = "kinozal.png"
						}
						if (magnetTrackers != null) {
							magnetLink += magnetTrackers;
						}
						var audio = "П.М."
						if (torrentInfo.audio == "D") {
							audio = "Дубляж"
						} else if (torrentInfo.audio == "L") {
							audio = "Лицензия"
						}
						page.appendItem(magnetLink, "directory", {
							title: new showtime.RichText((torrentInfo.type.replace(/\[\"|\"\]/g, '')) + ' ['+ audio +'] ' + Math.round(10 * torrentInfo.size / (1024 * 1024 * 1024)) / 10 + 'Гб ' + '(S: ' + coloredStr(torrentInfo.seeders, green) + '/ L: ' + coloredStr(torrentInfo.leechers, red) + ') '),
							icon: plugin.path + torIcon,
							description: torrentInfo.date
						});
					}
				}
			}
		}
		page.loading = false;
	});
})(this);
